%------------------------------------------------------------------------------ % File : lazyCoP---0.1 % Problem : GRA002+4 : TPTP v8.1.0. Bugfixed v3.2.0. % Transfm : none % Format : tptp:raw % Command : vampire -t 0 --mode clausify %d -updr off -nm 2 -erd input_only -icip on | lazycop % Computer : n032.cluster.edu % Model : x86_64 x86_64 % CPU : Intel(R) Xeon(R) CPU E5-2620 v4 2.10GHz % Memory : 8042.1875MB % OS : Linux 3.10.0-693.el7.x86_64 % CPULimit : 300s % WCLimit : 600s % DateTime : Sat Jul 16 07:18:57 EDT 2022 % Result : Theorem 13.86s 2.13s % Output : Assurance 0s % Verified : % SZS Type : - % Comments : %------------------------------------------------------------------------------ %----No solution output by system %------------------------------------------------------------------------------ %----ORIGINAL SYSTEM OUTPUT % 0.09/0.10 % Problem : GRA002+4 : TPTP v8.1.0. Bugfixed v3.2.0. % 0.09/0.10 % Command : vampire -t 0 --mode clausify %d -updr off -nm 2 -erd input_only -icip on | lazycop % 0.09/0.29 % Computer : n032.cluster.edu % 0.09/0.29 % Model : x86_64 x86_64 % 0.09/0.29 % CPU : Intel(R) Xeon(R) CPU E5-2620 v4 @ 2.10GHz % 0.09/0.29 % Memory : 8042.1875MB % 0.09/0.29 % OS : Linux 3.10.0-693.el7.x86_64 % 0.09/0.29 % CPULimit : 300 % 0.09/0.29 % WCLimit : 600 % 0.09/0.29 % DateTime : Tue May 31 02:25:13 EDT 2022 % 0.09/0.29 % CPUTime : % 13.86/2.13 % SZS status Theorem % 13.86/2.13 % SZS output begin IncompleteProof % 13.86/2.13 cnf(c0, axiom, % 13.86/2.13 complete). % 13.86/2.13 cnf(c1, plain, % 13.86/2.13 complete, % 13.86/2.13 inference(start, [], [c0])). % 13.86/2.13 % 13.86/2.13 cnf(c2, axiom, % 13.86/2.13 number_of_in(sequential_pairs,X0) = number_of_in(triangles,X0) | ~shortest_path(X1,X2,X0) | ~complete). % 13.86/2.13 cnf(c3, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(strict_predicate_extension, [], [c1, c2])). % 13.86/2.13 cnf(c4, plain, % 13.86/2.13 number_of_in(sequential_pairs,X0) = number_of_in(triangles,X0) | ~shortest_path(X1,X2,X0), % 13.86/2.13 inference(strict_predicate_extension, [], [c1, c2])). % 13.86/2.13 % 13.86/2.13 cnf(c5, axiom, % 13.86/2.13 less_or_equal(number_of_in(X3,X4),number_of_in(X3,graph))). % 13.86/2.13 cnf(a0, assumption, % 13.86/2.13 number_of_in(X3,X4) = number_of_in(triangles,X0)). % 13.86/2.13 cnf(a1, assumption, % 13.86/2.13 number_of_in(sequential_pairs,X0) = X5). % 13.86/2.13 cnf(c6, plain, % 13.86/2.13 ~shortest_path(X1,X2,X0), % 13.86/2.13 inference(strict_subterm_extension, [assumptions([a0, a1])], [c4, c5])). % 13.86/2.13 cnf(c7, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(strict_subterm_extension, [assumptions([a0, a1])], [c4, c5])). % 13.86/2.13 cnf(c8, plain, % 13.86/2.13 less_or_equal(X5,number_of_in(X3,graph)), % 13.86/2.13 inference(strict_subterm_extension, [assumptions([a0, a1])], [c4, c5])). % 13.86/2.13 % 13.86/2.13 cnf(c9, axiom, % 13.86/2.13 ~less_or_equal(minus(length_of(sK23),n1),number_of_in(triangles,graph))). % 13.86/2.13 cnf(a2, assumption, % 13.86/2.13 X6 = X5). % 13.86/2.13 cnf(a3, assumption, % 13.86/2.13 X7 = number_of_in(X3,graph)). % 13.86/2.13 cnf(c10, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(lazy_predicate_extension, [assumptions([a2, a3])], [c8, c9])). % 13.86/2.13 cnf(c11, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(lazy_predicate_extension, [assumptions([a2, a3])], [c8, c9])). % 13.86/2.13 cnf(c12, plain, % 13.86/2.13 minus(length_of(sK23),n1) != X6 | number_of_in(triangles,graph) != X7, % 13.86/2.13 inference(lazy_predicate_extension, [assumptions([a2, a3])], [c8, c9])). % 13.86/2.13 % 13.86/2.13 cnf(c13, axiom, % 13.86/2.13 number_of_in(sequential_pairs,X8) = minus(length_of(X8),n1) | ~path(X9,X10,X8)). % 13.86/2.13 cnf(a4, assumption, % 13.86/2.13 minus(length_of(sK23),n1) = minus(length_of(X8),n1)). % 13.86/2.13 cnf(c14, plain, % 13.86/2.13 number_of_in(triangles,graph) != X7, % 13.86/2.13 inference(strict_function_extension, [assumptions([a4])], [c12, c13])). % 13.86/2.13 cnf(c15, plain, % 13.86/2.13 ~path(X9,X10,X8), % 13.86/2.13 inference(strict_function_extension, [assumptions([a4])], [c12, c13])). % 13.86/2.13 cnf(c16, plain, % 13.86/2.13 X11 != number_of_in(sequential_pairs,X8) | X11 != X6, % 13.86/2.13 inference(strict_function_extension, [assumptions([a4])], [c12, c13])). % 13.86/2.13 % 13.86/2.13 cnf(a5, assumption, % 13.86/2.13 X11 = number_of_in(sequential_pairs,X8)). % 13.86/2.13 cnf(c17, plain, % 13.86/2.13 X11 != X6, % 13.86/2.13 inference(reflexivity, [assumptions([a5])], [c16])). % 13.86/2.13 % 13.86/2.13 cnf(a6, assumption, % 13.86/2.13 X11 = X6). % 13.86/2.13 cnf(c18, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(reflexivity, [assumptions([a6])], [c17])). % 13.86/2.13 % 13.86/2.13 cnf(c19, axiom, % 13.86/2.13 path(X12,X13,X14) | ~sP13(X14,X13,X12)). % 13.86/2.13 cnf(a7, assumption, % 13.86/2.13 X9 = X12). % 13.86/2.13 cnf(a8, assumption, % 13.86/2.13 X10 = X13). % 13.86/2.13 cnf(a9, assumption, % 13.86/2.13 X8 = X14). % 13.86/2.13 cnf(c20, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(strict_predicate_extension, [assumptions([a7, a8, a9])], [c15, c19])). % 13.86/2.13 cnf(c21, plain, % 13.86/2.13 ~sP13(X14,X13,X12), % 13.86/2.13 inference(strict_predicate_extension, [assumptions([a7, a8, a9])], [c15, c19])). % 13.86/2.13 % 13.86/2.13 cnf(c22, axiom, % 13.86/2.13 sP13(X15,X16,X17) | ~shortest_path(X17,X16,X15)). % 13.86/2.13 cnf(a10, assumption, % 13.86/2.13 X14 = X15). % 13.86/2.13 cnf(a11, assumption, % 13.86/2.13 X13 = X16). % 13.86/2.13 cnf(a12, assumption, % 13.86/2.13 X12 = X17). % 13.86/2.13 cnf(c23, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(strict_predicate_extension, [assumptions([a10, a11, a12])], [c21, c22])). % 13.86/2.13 cnf(c24, plain, % 13.86/2.13 ~shortest_path(X17,X16,X15), % 13.86/2.13 inference(strict_predicate_extension, [assumptions([a10, a11, a12])], [c21, c22])). % 13.86/2.13 % 13.86/2.13 cnf(c25, axiom, % 13.86/2.13 shortest_path(sK24,sK25,sK23)). % 13.86/2.13 cnf(a13, assumption, % 13.86/2.13 X17 = sK24). % 13.86/2.13 cnf(a14, assumption, % 13.86/2.13 X16 = sK25). % 13.86/2.13 cnf(a15, assumption, % 13.86/2.13 X15 = sK23). % 13.86/2.13 cnf(c26, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(strict_predicate_extension, [assumptions([a13, a14, a15])], [c24, c25])). % 13.86/2.13 cnf(c27, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(strict_predicate_extension, [assumptions([a13, a14, a15])], [c24, c25])). % 13.86/2.13 % 13.86/2.13 cnf(a16, assumption, % 13.86/2.13 number_of_in(triangles,graph) = X7). % 13.86/2.13 cnf(c28, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(reflexivity, [assumptions([a16])], [c14])). % 13.86/2.13 % 13.86/2.13 cnf(c29, plain, % 13.86/2.13 shortest_path(X17,X16,X15)). % 13.86/2.13 cnf(a17, assumption, % 13.86/2.13 X1 = X17). % 13.86/2.13 cnf(a18, assumption, % 13.86/2.13 X2 = X16). % 13.86/2.13 cnf(a19, assumption, % 13.86/2.13 X0 = X15). % 13.86/2.13 cnf(c30, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(predicate_reduction, [assumptions([a17, a18, a19])], [c6, c29])). % 13.86/2.13 % 13.86/2.13 cnf(c31, plain, % 13.86/2.13 $false, % 13.86/2.13 inference(constraint_solving, [ % 13.86/2.13 bind(X0, sK23), % 13.86/2.13 bind(X1, sK24), % 13.86/2.13 bind(X2, sK25), % 13.86/2.13 bind(X3, triangles), % 13.86/2.13 bind(X4, sK23), % 13.86/2.13 bind(X5, number_of_in(sequential_pairs,X0)), % 13.86/2.13 bind(X6, number_of_in(sequential_pairs,X0)), % 13.86/2.13 bind(X7, number_of_in(X3,graph)), % 13.86/2.13 bind(X8, sK23), % 13.86/2.13 bind(X9, sK24), % 13.86/2.13 bind(X10, sK25), % 13.86/2.13 bind(X11, number_of_in(sequential_pairs,X8)), % 13.86/2.13 bind(X12, sK24), % 13.86/2.13 bind(X13, sK25), % 13.86/2.13 bind(X14, sK23), % 13.86/2.13 bind(X15, sK23), % 13.86/2.13 bind(X16, sK25), % 13.86/2.13 bind(X17, sK24) % 13.86/2.13 ], % 13.86/2.13 [a0, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12, a13, a14, a15, a16, a17, a18, a19])). % 13.86/2.13 % 13.86/2.13 % SZS output end IncompleteProof %------------------------------------------------------------------------------